@@ -3,4 +3,8 @@ from .calculate_feature_matrix import (
     approximate_features,
     calculate_feature_matrix
 )
-from .utils import bin_cutoff_times, create_client_and_cluster
+from .utils import (
+    bin_cutoff_times,
+    create_client_and_cluster,
+    replace_inf_values
+)
