@@ -2,28 +2,26 @@ import warnings
 
 import numpy as np
 import pandas as pd
+from woodwork.column_schema import ColumnSchema
+from woodwork.logical_types import (
+    URL,
+    AgeFractional,
+    Boolean,
+    BooleanNullable,
+    Categorical,
+    Datetime,
+    EmailAddress,
+    LatLong,
+    NaturalLanguage,
+    Ordinal
+)
 
 from featuretools.primitives.base.transform_primitive_base import (
     TransformPrimitive
 )
 from featuretools.utils import convert_time_units
 from featuretools.utils.common_tld_utils import COMMON_TLDS
-from featuretools.utils.entity_utils import replace_latlong_nan
 from featuretools.utils.gen_utils import Library
-from featuretools.variable_types import (
-    URL,
-    Boolean,
-    Categorical,
-    DateOfBirth,
-    Datetime,
-    DatetimeTimeIndex,
-    EmailAddress,
-    LatLong,
-    NaturalLanguage,
-    Numeric,
-    Ordinal,
-    Variable
-)
 
 
 class IsNull(TransformPrimitive):
@@ -35,8 +33,8 @@ class IsNull(TransformPrimitive):
         [False, True, False]
     """
     name = "is_null"
-    input_types = [Variable]
-    return_type = Boolean
+    input_types = [ColumnSchema()]
+    return_type = ColumnSchema(logical_type=Boolean)
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "whether {} is null"
 
@@ -55,8 +53,8 @@ class Absolute(TransformPrimitive):
         [3.0, 5.0, 2.4]
     """
     name = "absolute"
-    input_types = [Numeric]
-    return_type = Numeric
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the absolute value of {}"
 
@@ -89,8 +87,8 @@ class TimeSincePrevious(TransformPrimitive):
         [nan, 120.0, 60.0, -30.0, 450.0]
     """
     name = "time_since_previous"
-    input_types = [DatetimeTimeIndex]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=Datetime, semantic_tags={'time_index'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     description_template = "the time since the previous instance of {}"
 
     def __init__(self, unit="seconds"):
@@ -115,8 +113,8 @@ class Day(TransformPrimitive):
         [1, 3, 31]
     """
     name = "day"
-    input_types = [Datetime]
-    return_type = Ordinal
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 32))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the day of the month of {}"
 
@@ -139,8 +137,8 @@ class Hour(TransformPrimitive):
         [0, 11, 19]
     """
     name = "hour"
-    input_types = [Datetime]
-    return_type = Ordinal
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(24))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = 'the hour value of {}'
 
@@ -163,8 +161,8 @@ class Second(TransformPrimitive):
         [0, 50, 15]
     """
     name = "second"
-    input_types = [Datetime]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(60))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the seconds value of {}"
 
@@ -187,8 +185,8 @@ class Minute(TransformPrimitive):
         [0, 10, 45]
     """
     name = "minute"
-    input_types = [Datetime]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(60))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the minutes value of {}"
 
@@ -216,8 +214,8 @@ class Week(TransformPrimitive):
         [1, 25, 48]
         """
     name = "week"
-    input_types = [Datetime]
-    return_type = Ordinal
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 54))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the week of the year of {}"
 
@@ -245,8 +243,8 @@ class Month(TransformPrimitive):
         [3, 6, 11]
     """
     name = "month"
-    input_types = [Datetime]
-    return_type = Ordinal
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 13))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the month of {}"
 
@@ -269,8 +267,8 @@ class Year(TransformPrimitive):
         [2019, 2048, 1950]
     """
     name = "year"
-    input_types = [Datetime]
-    return_type = Ordinal
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(1, 3000))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the year of {}"
 
@@ -293,8 +291,8 @@ class IsWeekend(TransformPrimitive):
         [False, False, True]
     """
     name = "is_weekend"
-    input_types = [Datetime]
-    return_type = Boolean
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "whether {} occurred on a weekend"
 
@@ -321,8 +319,8 @@ class Weekday(TransformPrimitive):
         [4, 0, 5]
     """
     name = "weekday"
-    input_types = [Datetime]
-    return_type = Ordinal
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(logical_type=Ordinal(order=list(range(7))), semantic_tags={'category'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the day of the week of {}"
 
@@ -343,8 +341,8 @@ class NumCharacters(TransformPrimitive):
         [16, 11, 6]
     """
     name = 'num_characters'
-    input_types = [NaturalLanguage]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=NaturalLanguage)]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the number of characters in {}"
 
@@ -366,8 +364,8 @@ class NumWords(TransformPrimitive):
         [4, 2, 1, 6]
     """
     name = 'num_words'
-    input_types = [NaturalLanguage]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=NaturalLanguage)]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the number of words in {}"
 
@@ -409,8 +407,8 @@ class TimeSince(TransformPrimitive):
         [-1000, -1000000000, -120000000000]
     """
     name = 'time_since'
-    input_types = [Datetime]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=Datetime)]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     uses_calc_time = True
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "the time from {} to the cutoff time"
@@ -434,8 +432,8 @@ class IsIn(TransformPrimitive):
         [True, False, True]
     """
     name = "isin"
-    input_types = [Variable]
-    return_type = Boolean
+    input_types = [ColumnSchema()]
+    return_type = ColumnSchema(logical_type=Boolean)
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
 
     def __init__(self, list_of_outputs=None):
@@ -473,9 +471,9 @@ class Diff(TransformPrimitive):
         [nan, 9.0, -7.0, 1.0, 11.0]
     """
     name = "diff"
-    input_types = [Numeric]
-    return_type = Numeric
-    uses_full_entity = True
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
+    uses_full_dataframe = True
     description_template = "the difference from the previous value of {}"
 
     def get_function(self):
@@ -493,8 +491,8 @@ class Negate(TransformPrimitive):
         [-1.0, -23.2, 7.0]
     """
     name = "negate"
-    input_types = [Numeric]
-    return_type = Numeric
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the negation of {}"
 
@@ -516,8 +514,8 @@ class Not(TransformPrimitive):
         [False, False, True]
     """
     name = "not"
-    input_types = [Boolean]
-    return_type = Boolean
+    input_types = [[ColumnSchema(logical_type=Boolean)], [ColumnSchema(logical_type=BooleanNullable)]]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
     compatibility = [Library.PANDAS, Library.DASK, Library.KOALAS]
     description_template = "the negation of {}"
 
@@ -542,9 +540,9 @@ class Percentile(TransformPrimitive):
         [0.5, 0.75, 0.25, nan, 1.0]
     """
     name = 'percentile'
-    uses_full_entity = True
-    input_types = [Numeric]
-    return_type = Numeric
+    uses_full_dataframe = True
+    input_types = [ColumnSchema(semantic_tags={'numeric'})]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     description_template = "the percentile rank of {}"
 
     def get_function(self):
@@ -553,7 +551,7 @@ class Percentile(TransformPrimitive):
 
 class Latitude(TransformPrimitive):
     """Returns the first tuple value in a list of LatLong tuples.
-       For use with the LatLong variable type.
+       For use with the LatLong logical type.
 
     Examples:
         >>> latitude = Latitude()
@@ -563,21 +561,19 @@ class Latitude(TransformPrimitive):
         [42.4, 40.0, 41.2]
     """
     name = 'latitude'
-    input_types = [LatLong]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=LatLong)]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     description_template = "the latitude of {}"
 
     def get_function(self):
         def latitude(latlong):
-            if latlong.hasnans:
-                latlong = replace_latlong_nan(latlong)
-            return latlong.map(lambda x: x[0])
+            return latlong.map(lambda x: x[0] if isinstance(x, tuple) else np.nan)
         return latitude
 
 
 class Longitude(TransformPrimitive):
     """Returns the second tuple value in a list of LatLong tuples.
-       For use with the LatLong variable type.
+       For use with the LatLong logical type.
 
     Examples:
         >>> longitude = Longitude()
@@ -587,21 +583,18 @@ class Longitude(TransformPrimitive):
         [-71.1, -122.4, -96.75]
     """
     name = 'longitude'
-    input_types = [LatLong]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=LatLong)]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     description_template = "the longitude of {}"
 
     def get_function(self):
         def longitude(latlong):
-            if latlong.hasnans:
-                latlong = replace_latlong_nan(latlong)
-            return latlong.map(lambda x: x[1])
+            return latlong.map(lambda x: x[1] if isinstance(x, tuple) else np.nan)
         return longitude
 
 
 class Haversine(TransformPrimitive):
-    """Calculates the approximate haversine distance between two LatLong
-        variable types.
+    """Calculates the approximate haversine distance between two LatLong columns.
 
         Args:
             unit (str): Determines the unit value to output. Could
@@ -623,8 +616,8 @@ class Haversine(TransformPrimitive):
             [4234.555, 2161.814]
     """
     name = 'haversine'
-    input_types = [LatLong, LatLong]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=LatLong), ColumnSchema(logical_type=LatLong)]
+    return_type = ColumnSchema(semantic_tags={'numeric'})
     commutative = True
 
     def __init__(self, unit='miles'):
@@ -637,14 +630,10 @@ class Haversine(TransformPrimitive):
 
     def get_function(self):
         def haversine(latlong1, latlong2):
-            if latlong1.hasnans:
-                latlong1 = replace_latlong_nan(latlong1)
-            if latlong2.hasnans:
-                latlong2 = replace_latlong_nan(latlong2)
-            lat_1s = np.array([x[0] for x in latlong1])
-            lon_1s = np.array([x[1] for x in latlong1])
-            lat_2s = np.array([x[0] for x in latlong2])
-            lon_2s = np.array([x[1] for x in latlong2])
+            lat_1s = np.array([x[0] if isinstance(x, tuple) else np.nan for x in latlong1])
+            lon_1s = np.array([x[1] if isinstance(x, tuple) else np.nan for x in latlong1])
+            lat_2s = np.array([x[0] if isinstance(x, tuple) else np.nan for x in latlong2])
+            lon_2s = np.array([x[1] if isinstance(x, tuple) else np.nan for x in latlong2])
             lon1, lat1, lon2, lat2 = map(
                 np.radians, [lon_1s, lat_1s, lon_2s, lat_2s])
             dlon = lon2 - lon1
@@ -688,8 +677,8 @@ class Age(TransformPrimitive):
         [19.013698630136986, 35.61643835616438, 21.221917808219178]
     """
     name = "age"
-    input_types = [DateOfBirth]
-    return_type = Numeric
+    input_types = [ColumnSchema(logical_type=Datetime, semantic_tags={'date_of_birth'})]
+    return_type = ColumnSchema(logical_type=AgeFractional, semantic_tags={'numeric'})
     uses_calc_time = True
     compatibility = [Library.PANDAS, Library.DASK]
     description_template = "the age from {}"
@@ -716,8 +705,8 @@ class URLToDomain(TransformPrimitive):
         ['play.google.com', 'google.co.in', 'facebook.com']
     """
     name = "url_to_domain"
-    input_types = [URL]
-    return_type = Categorical
+    input_types = [ColumnSchema(logical_type=URL)]
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
 
     def get_function(self):
         def url_to_domain(x):
@@ -743,8 +732,8 @@ class URLToProtocol(TransformPrimitive):
         ['https', 'http', nan]
     """
     name = "url_to_protocol"
-    input_types = [URL]
-    return_type = Categorical
+    input_types = [ColumnSchema(logical_type=URL)]
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
 
     def get_function(self):
         def url_to_protocol(x):
@@ -771,8 +760,8 @@ class URLToTLD(TransformPrimitive):
         ['com', 'in', 'com']
     """
     name = "url_to_tld"
-    input_types = [URL]
-    return_type = Categorical
+    input_types = [ColumnSchema(logical_type=URL)]
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
 
     def get_function(self):
         self.tlds_pattern = r'(?:\.({}))'.format('|'.join(COMMON_TLDS))
@@ -804,8 +793,8 @@ class IsFreeEmailDomain(TransformPrimitive):
         [True, False]
     """
     name = "is_free_email_domain"
-    input_types = [EmailAddress]
-    return_type = Boolean
+    input_types = [ColumnSchema(logical_type=EmailAddress)]
+    return_type = ColumnSchema(logical_type=BooleanNullable)
 
     filename = "free_email_provider_domains.txt"
 
@@ -854,8 +843,8 @@ class EmailAddressToDomain(TransformPrimitive):
         ['gmail.com', 'featuretools.com']
     """
     name = "email_address_to_domain"
-    input_types = [EmailAddress]
-    return_type = Categorical
+    input_types = [ColumnSchema(logical_type=EmailAddress)]
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
 
     def get_function(self):
         def email_address_to_domain(emails):
