@@ -1,8 +1,15 @@
 import urllib.request
 
+import pandas as pd
 import pytest
 
-from featuretools.demo import load_flight, load_mock_customer, load_retail
+from featuretools import EntitySet
+from featuretools.demo import (
+    load_flight,
+    load_mock_customer,
+    load_retail,
+    load_weather
+)
 
 
 @pytest.fixture(autouse=True)
@@ -15,6 +22,7 @@ def set_testing_headers():
 def test_load_retail_diff():
     nrows = 10
     es_first = load_retail(nrows=nrows)
+    assert isinstance(es_first, EntitySet)
     assert es_first['order_products'].shape[0] == nrows
     nrows_second = 11
     es_second = load_retail(nrows=nrows_second)
@@ -28,6 +36,7 @@ def test_mock_customer():
     n_transactions = 400
     es = load_mock_customer(n_customers=n_customers, n_products=n_products, n_sessions=n_sessions,
                             n_transactions=n_transactions, random_seed=0, return_entityset=True)
+    assert isinstance(es, EntitySet)
     df_names = [df.ww.name for df in es.dataframes]
     expected_names = ['transactions', 'products', 'sessions', 'customers']
     assert set(expected_names) == set(df_names)
@@ -41,7 +50,19 @@ def test_load_flight():
     es = load_flight(month_filter=[1],
                      categorical_filter={'origin_city': ['Charlotte, NC']},
                      return_single_table=False, nrows=1000)
+    assert isinstance(es, EntitySet)
     dataframe_names = ['airports', 'flights', 'trip_logs', 'airlines']
     realvals = [(11, 3), (13, 9), (103, 21), (1, 1)]
     for i, name in enumerate(dataframe_names):
         assert es[name].shape == realvals[i]
+
+
+def test_weather():
+    es = load_weather()
+    assert isinstance(es, EntitySet)
+    dataframe_names = ['temperatures']
+    realvals = [(3650, 3)]
+    for i, name in enumerate(dataframe_names):
+        assert es[name].shape == realvals[i]
+    es = load_weather(return_single_table=True)
+    assert isinstance(es, pd.DataFrame)
